"""
:copyright: (c) 2023-present SqdNoises
:license: MIT, see LICENSE for more details.
"""

__title__ = "song-edit"
__full_title__ = "sqd-song-edit"
__description__ = "edit song cover art and metadeta easily!"
__version__ = "1.1.1"

__author__ = "SqdNoises"
__license__ = "MIT"
__copyright__ = "Copyright 2023-present SqdNoises"

from .start import main as start
from . import color
colour = color